ForkValidationError<S> class final

Thrown when a ForkState fails structural validation.

Inheritance

Constructors

ForkValidationError(S forkId, String details)
Thrown when a ForkState fails structural validation.

Properties

details String
Additional details about the validation failure.
final
forkId → S
The identifier of the invalid fork state.
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable message describing the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited