ParallelBlueprint<S, E> class

A compound state in which each direct child forms a region.

A parallel state is like a CompositeState except that all direct children are active at the same time - meaning they each have the ability to handle events.

Inheritance

Constructors

ParallelBlueprint({required S id, List<BasicBlueprint<S, E>> children = const [], StateFunction? entry, StateFunction? exit, Map<E, TransitionBlueprint<S, E>>? on, List<CompletionBlueprint<S, E>>? completion})
Creates a new ParallelBlueprint with the specified configuration.

Properties

children List<BasicBlueprint<S, E>>
The list of direct descendants of this state.
finalinherited
completion List<CompletionBlueprint<S, E>>?
Completion handlers are evaluated when a substate enters this state's FinalBlueprint child.
finalinherited
defer Set<E>
The set of events that this state defers for later processing.
finalinherited
entry StateFunction?
The effect behavior executed when this state is entered.
finalinherited
exit StateFunction?
The effect behavior executed when this state is exited.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id → S
The unique identifier for this state.
finalinherited
initial → S?
Optional unique identifier of the default state to transition to when entered via the default entry mechanism (i.e. not history).
finalinherited
initialAction StateFunction?
The effect behavior executed when the initial state is entered.
finalinherited
on Map<E, TransitionBlueprint<S, E>>?
The map of event handlers for this state.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited