PlantUmlEncoder<S, E> class

An encoder that converts a MachineBlueprint into a PlantUML string.

Constructors

PlantUmlEncoder({String? direction, List<String> skinparams = const [], ParallelSeparator parallelSeparator = ParallelSeparator.horizontal})
Creates a new PlantUmlEncoder with the specified options.

Properties

direction String?
Options for configuring the layout direction (e.g., 'left to right').
final
hashCode int
The hash code for this object.
no setterinherited
parallelSeparator ParallelSeparator
The separator to use for parallel regions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skinparams List<String>
Custom PlantUML skin parameters to include in the output.
final

Methods

encode(MachineBlueprint<S, E> blueprint) String
Encodes the given blueprint into a PlantUML string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited