MissingStateError<S> class
final
Thrown when a transition or initial state targets a non-existent state.
- Inheritance
-
- Object
- ValidationError
- MissingStateError
Constructors
- MissingStateError(S id, S sourceId, String context)
- Thrown when a transition or initial state targets a non-existent state.
Properties
- context → String
-
A string describing the context of the missing state (e.g. 'initial state').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → S
-
The identifier of the missing state.
final
- message → String
-
A human-readable message describing the error.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceId → S
-
The identifier of the state containing the invalid target.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited